KeyboardPressBuilder

Struct KeyboardPressBuilder 

pub struct KeyboardPressBuilder<'a> { /* private fields */ }
Builder for keyboard press operations with configurable options.

Created via Keyboard::press.

Implementations

Source

impl<'a> KeyboardPressBuilder<'a>

pub fn delay(self, delay: Duration) -> Self

Set a delay between key down and key up.

pub fn no_wait_after(self, no_wait_after: bool) -> Self

Whether to skip waiting for navigation after the key press.

By default, the press will wait for any triggered navigation to complete. Set to true to return immediately after the key is pressed.

pub async fn send(self) -> Result<(), LocatorError>

Execute the press operation.