FillBuilder

Struct FillBuilder 

pub struct FillBuilder<'l, 'a> { /* private fields */ }
Builder for fill operations with configurable options.

Created via Locator::fill.

Implementations

Source

impl<'l, 'a> FillBuilder<'l, 'a>

pub fn no_wait_after(self, no_wait_after: bool) -> Self

Whether to skip waiting for navigation after the fill.

By default, the fill will wait for any triggered navigation to complete. Set to true to return immediately after the text is filled.

pub async fn send(self) -> Result<(), LocatorError>

Execute the fill operation.