pub struct WebError { /* private fields */ }Expand description
An error from any page in a browser context.
Web errors are emitted at the context level when any page has an uncaught exception. They include a reference to the page where the error occurred.
Example
context.on_weberror(|error| async move {
println!("Error: {}", error.message());
}).await;Implementations
Sourceimpl WebError
impl WebError
Sourcepub fn session_id(&self) -> &str
pub fn session_id(&self) -> &str
Get the session ID of the page.
Sourcepub fn page_error(&self) -> &PageError
pub fn page_error(&self) -> &PageError
Get the underlying page error.