pub struct KeyboardPressBuilder<'a> { /* private fields */ }Expand description
Builder for keyboard press operations with configurable options.
Created via Keyboard::press.
Implementations
Sourceimpl<'a> KeyboardPressBuilder<'a>
impl<'a> KeyboardPressBuilder<'a>
Sourcepub fn no_wait_after(self, no_wait_after: bool) -> Self
pub fn no_wait_after(self, no_wait_after: bool) -> Self
Whether to skip waiting for navigation after the key press.
By default, the press will wait for any triggered navigation to complete.
Set to true to return immediately after the key is pressed.
Sourcepub async fn send(self) -> Result<(), LocatorError>
pub async fn send(self) -> Result<(), LocatorError>
Execute the press operation.