pub struct FillBuilder<'l, 'a> { /* private fields */ }Expand description
Builder for fill operations with configurable options.
Created via Locator::fill.
Implementations
Sourceimpl<'l, 'a> FillBuilder<'l, 'a>
impl<'l, 'a> FillBuilder<'l, 'a>
Sourcepub fn no_wait_after(self, no_wait_after: bool) -> Self
pub fn no_wait_after(self, no_wait_after: bool) -> Self
Whether to skip waiting for navigation after the fill.
By default, the fill will wait for any triggered navigation to complete.
Set to true to return immediately after the text is filled.
Sourcepub async fn send(self) -> Result<(), LocatorError>
pub async fn send(self) -> Result<(), LocatorError>
Execute the fill operation.